#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# launch_dialog.pyw
# 
# let the user launch an app in a vm
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright 2013-2014 X-Net and AIT Austrian Institute of Technology
# 
# 
#     X-Net Services GmbH
#     Elisabethstrasse 1
#     4020 Linz
#     AUSTRIA
#     https://www.x-net.at
# 
#     AIT Austrian Institute of Technology
#     Donau City Strasse 1
#     1220 Wien
#     AUSTRIA
#     http://www.ait.ac.at
# 
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

from ui_LaunchDialog import Ui_LaunchDialog 
from about_dialog import AboutDialog


# ------------------------------------------------------------
# code


class LaunchDialog(QtGui.QDialog):

    """A dialog for letting the user launch an arbitrary app in a vm"""

    def __init__(self, vms, apps):

        QtGui.QDialog.__init__(self)

        # setup the user interface
        self.ui = Ui_LaunchDialog()
        self.ui.setupUi(self)
        for v in vms: 
            self.ui.cmbVM.addItem(v)
        for a in apps: 
            self.ui.cmbApplication.addItem(a)
    
        # local members
        self._about_dialog = AboutDialog()

        # connectors
        self.ui.btnAbout.clicked.connect(self.clicked_about)
        self.ui.btnCancel.clicked.connect(self.reject)
        self.ui.btnOk.clicked.connect(self.clicked_ok)

        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)
 

    def clicked_about(self):

        """About button has been clicked."""
        self._about_dialog.show()


    def clicked_ok(self):
        
        """Ok button has been clicked."""
        sys.stdout.write('{ ')
        sys.stdout.write('"application": "')
        sys.stdout.write(self.app)
        sys.stdout.write('", ')
        sys.stdout.write('"vm": "')
        sys.stdout.write(self.vm)
        sys.stdout.write('" ')
        sys.stdout.write('}\n')
        self.accept()


    @property
    def app(self):

        """The application of the user."""
        return str(self.ui.cmbApplication.currentText())
 

    @property
    def vm(self):

        """The application of the user."""
        return str(self.ui.cmbVM.currentText())
 

if __name__ == "__main__":
    a = QtGui.QApplication(sys.argv)
    d = LaunchDialog(['SecurityDVM0', 'SecurityDVM1'], ['/usr/bin/xterm', '/usr/bin/xclock', '/usr/bin/xeyes'])
    d.show()
    sys.exit(a.exec_())     

