#!/bin/env python
# -*- coding: utf-8 -*-

# ------------------------------------------------------------
# notification_dialog.pyw
# 
# the user should give us a notification
#
# Autor: Oliver Maurhart, <oliver.maurhart@ait.ac.at>
#
# Copyright 2013-2014 X-Net and AIT Austrian Institute of Technology
# 
# 
#     X-Net Services GmbH
#     Elisabethstrasse 1
#     4020 Linz
#     AUSTRIA
#     https://www.x-net.at
# 
#     AIT Austrian Institute of Technology
#     Donau City Strasse 1
#     1220 Wien
#     AUSTRIA
#     http://www.ait.ac.at
# 
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#    http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ------------------------------------------------------------


# ------------------------------------------------------------
# imports

import sys

from PyQt4 import QtCore
from PyQt4 import QtGui

from ui_NotificationDialog import Ui_NotificationDialog 
from about_dialog import AboutDialog


# ------------------------------------------------------------
# code


class NotificationDialog(QtGui.QDialog):

    """A dialog for letting the user pass on a user/notification combo"""

    def __init__(self, caption = 'OpenSecurity Notification', message = 'This is a notification from the OpenSecurity System.'):

        QtGui.QDialog.__init__(self)

        # setup the user interface
        self.ui = Ui_NotificationDialog()
        self.ui.setupUi(self)
        self.setWindowTitle(caption)

        # local members
        self._about_dialog = AboutDialog()

        # connectors
        self.ui.lblMessage.setText(message)
        self.ui.btnAbout.clicked.connect(self.clicked_about)
        self.ui.btnOk.clicked.connect(self.accept)

        # positionate ourself central
        screen = QtGui.QDesktopWidget().screenGeometry()
        size = self.geometry()
        self.move((screen.width() - size.width()) / 2, (screen.height() - size.height()) / 2)
 

    def clicked_about(self):

        """About button has been clicked."""
        self._about_dialog.show()


    def clicked_ok(self):
        
        """Ok button has been clicked."""
        sys.stdout.write('{ ')
        sys.stdout.write('\'notification\': \'')
        sys.stdout.write(self.ui.edtNotification.text())
        sys.stdout.write('\' ')
        sys.stdout.write('}\n')
        self.accept()


    def set_user_text(user_text):

        """Set a text to explain which notification we need."""
        self.ui.lblText.setText(user_text)


if __name__ == "__main__":
    a = QtGui.QApplication(sys.argv)
    d = NotificationDialog()
    d.show()
    sys.exit(a.exec_())     

